==> codelite_8.0.1+dfsg.orig.tar.gz: codelite-8.0-1/Plugin/clBoostrapWizardPage.cpp <==
#include "clBoostrapWizardPage.h"
#include "clBootstrapWizard.h"

clBoostrapWizardPageWelcome::clBoostrapWizardPageWelcome(wxWizard* parent,
                                                         wxWizardPage* prev,
                                                         wxWizardPage* next,
                                                         const wxBitmap& bitmap)
{
    wxUnusedVar(bitmap);
    Create(parent, prev, next, clBootstrapWizard::GenerateBitmap(0));
}

clBoostrapWizardPagePlugins::clBoostrapWizardPagePlugins(wxWizard* parent,
                                                         wxWizardPage* prev,
                                                         wxWizardPage* next,
                                                         const wxBitmap& bitmap)
{
    wxUnusedVar(bitmap);
    Create(parent, prev, next, clBootstrapWizard::GenerateBitmap(1));
}

clBoostrapWizardPageCompilers::clBoostrapWizardPageCompilers(wxWizard* parent,
                                                             wxWizardPage* prev,
                                                             wxWizardPage* next,
                                                             const wxBitmap& bitmap)
{
    wxUnusedVar(bitmap);
    Create(parent, prev, next, clBootstrapWizard::GenerateBitmap(2));
}

clBoostrapWizardPageColours::clBoostrapWizardPageColours(wxWizard* parent,
                                                         wxWizardPage* prev,
                                                         wxWizardPage* next,
                                                         const wxBitmap& bitmap)
{
    wxUnusedVar(bitmap);
    Create(parent, prev, next, clBootstrapWizard::GenerateBitmap(3));
}

clBoostrapWizardPageWhitespace::clBoostrapWizardPageWhitespace(wxWizard* parent,
                                                               wxWizardPage* prev,
                                                               wxWizardPage* next,
                                                               const wxBitmap& bitmap)
{
    wxUnusedVar(bitmap);
    Create(parent, prev, next, clBootstrapWizard::GenerateBitmap(4));
}

==> codelite_10.0+dfsg.orig.tar.gz: codelite-10.0/Plugin/clBoostrapWizardPage.cpp <==
#include "clBoostrapWizardPage.h"
#include "clBootstrapWizard.h"

clBoostrapWizardPageWelcome::clBoostrapWizardPageWelcome(wxWizard* parent,
                                                         wxWizardPage* prev,
                                                         wxWizardPage* next,
                                                         const wxBitmap& bitmap)
{
    wxUnusedVar(bitmap);
    Create(parent, prev, next);
}

clBoostrapWizardPagePlugins::clBoostrapWizardPagePlugins(wxWizard* parent,
                                                         wxWizardPage* prev,
                                                         wxWizardPage* next,
                                                         const wxBitmap& bitmap)
{
    wxUnusedVar(bitmap);
    Create(parent, prev, next);
}

clBoostrapWizardPageCompilers::clBoostrapWizardPageCompilers(wxWizard* parent,
                                                             wxWizardPage* prev,
                                                             wxWizardPage* next,
                                                             const wxBitmap& bitmap)
{
    wxUnusedVar(bitmap);
    Create(parent, prev, next);
}

clBoostrapWizardPageColours::clBoostrapWizardPageColours(wxWizard* parent,
                                                         wxWizardPage* prev,
                                                         wxWizardPage* next,
                                                         const wxBitmap& bitmap)
{
    wxUnusedVar(bitmap);
    Create(parent, prev, next);
}

clBoostrapWizardPageWhitespace::clBoostrapWizardPageWhitespace(wxWizard* parent,
                                                               wxWizardPage* prev,
                                                               wxWizardPage* next,
                                                               const wxBitmap& bitmap)
{
    wxUnusedVar(bitmap);
    Create(parent, prev, next);
}
